@@ -69,7 +69,7 @@ class Exceptions:
 
 class EMRContainersClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/emr-containers.html#EMRContainers.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.4/reference/services/emr-containers.html#EMRContainers.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html)
     """
 
@@ -85,7 +85,7 @@ class EMRContainersClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/emr-containers.html#EMRContainers.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.4/reference/services/emr-containers.html#EMRContainers.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#can_paginate)
         """
 
@@ -93,7 +93,7 @@ class EMRContainersClient(BaseClient):
         """
         Cancels a job run.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/emr-containers.html#EMRContainers.Client.cancel_job_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.4/reference/services/emr-containers.html#EMRContainers.Client.cancel_job_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#cancel_job_run)
         """
 
@@ -105,15 +105,15 @@ class EMRContainersClient(BaseClient):
         type: str,
         releaseLabel: str,
         executionRoleArn: str,
-        certificateArn: str,
         clientToken: str,
+        certificateArn: str = ...,
         configurationOverrides: "ConfigurationOverridesTypeDef" = ...,
         tags: Mapping[str, str] = ...
     ) -> CreateManagedEndpointResponseTypeDef:
         """
         Creates a managed endpoint.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/emr-containers.html#EMRContainers.Client.create_managed_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.4/reference/services/emr-containers.html#EMRContainers.Client.create_managed_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#create_managed_endpoint)
         """
 
@@ -128,7 +128,7 @@ class EMRContainersClient(BaseClient):
         """
         Creates a virtual cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/emr-containers.html#EMRContainers.Client.create_virtual_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.4/reference/services/emr-containers.html#EMRContainers.Client.create_virtual_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#create_virtual_cluster)
         """
 
@@ -138,7 +138,7 @@ class EMRContainersClient(BaseClient):
         """
         Deletes a managed endpoint.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/emr-containers.html#EMRContainers.Client.delete_managed_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.4/reference/services/emr-containers.html#EMRContainers.Client.delete_managed_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#delete_managed_endpoint)
         """
 
@@ -146,7 +146,7 @@ class EMRContainersClient(BaseClient):
         """
         Deletes a virtual cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/emr-containers.html#EMRContainers.Client.delete_virtual_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.4/reference/services/emr-containers.html#EMRContainers.Client.delete_virtual_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#delete_virtual_cluster)
         """
 
@@ -154,7 +154,7 @@ class EMRContainersClient(BaseClient):
         """
         Displays detailed information about a job run.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/emr-containers.html#EMRContainers.Client.describe_job_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.4/reference/services/emr-containers.html#EMRContainers.Client.describe_job_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#describe_job_run)
         """
 
@@ -164,7 +164,7 @@ class EMRContainersClient(BaseClient):
         """
         Displays detailed information about a managed endpoint.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/emr-containers.html#EMRContainers.Client.describe_managed_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.4/reference/services/emr-containers.html#EMRContainers.Client.describe_managed_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#describe_managed_endpoint)
         """
 
@@ -172,7 +172,7 @@ class EMRContainersClient(BaseClient):
         """
         Displays detailed information about a specified virtual cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/emr-containers.html#EMRContainers.Client.describe_virtual_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.4/reference/services/emr-containers.html#EMRContainers.Client.describe_virtual_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#describe_virtual_cluster)
         """
 
@@ -186,7 +186,7 @@ class EMRContainersClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/emr-containers.html#EMRContainers.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.4/reference/services/emr-containers.html#EMRContainers.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#generate_presigned_url)
         """
 
@@ -204,7 +204,7 @@ class EMRContainersClient(BaseClient):
         """
         Lists job runs based on a set of parameters.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/emr-containers.html#EMRContainers.Client.list_job_runs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.4/reference/services/emr-containers.html#EMRContainers.Client.list_job_runs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#list_job_runs)
         """
 
@@ -222,7 +222,7 @@ class EMRContainersClient(BaseClient):
         """
         Lists managed endpoints based on a set of parameters.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/emr-containers.html#EMRContainers.Client.list_managed_endpoints)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.4/reference/services/emr-containers.html#EMRContainers.Client.list_managed_endpoints)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#list_managed_endpoints)
         """
 
@@ -230,7 +230,7 @@ class EMRContainersClient(BaseClient):
         """
         Lists the tags assigned to the resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/emr-containers.html#EMRContainers.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.4/reference/services/emr-containers.html#EMRContainers.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#list_tags_for_resource)
         """
 
@@ -248,7 +248,7 @@ class EMRContainersClient(BaseClient):
         """
         Lists information about the specified virtual cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/emr-containers.html#EMRContainers.Client.list_virtual_clusters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.4/reference/services/emr-containers.html#EMRContainers.Client.list_virtual_clusters)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#list_virtual_clusters)
         """
 
@@ -267,7 +267,7 @@ class EMRContainersClient(BaseClient):
         """
         Starts a job run.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/emr-containers.html#EMRContainers.Client.start_job_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.4/reference/services/emr-containers.html#EMRContainers.Client.start_job_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#start_job_run)
         """
 
@@ -275,7 +275,7 @@ class EMRContainersClient(BaseClient):
         """
         Assigns tags to resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/emr-containers.html#EMRContainers.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.4/reference/services/emr-containers.html#EMRContainers.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#tag_resource)
         """
 
@@ -283,14 +283,14 @@ class EMRContainersClient(BaseClient):
         """
         Removes tags from resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/emr-containers.html#EMRContainers.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.4/reference/services/emr-containers.html#EMRContainers.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#untag_resource)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_job_runs"]) -> ListJobRunsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.4/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listjobrunspaginator)
         """
 
@@ -299,7 +299,7 @@ class EMRContainersClient(BaseClient):
         self, operation_name: Literal["list_managed_endpoints"]
     ) -> ListManagedEndpointsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.4/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listmanagedendpointspaginator)
         """
 
@@ -308,6 +308,6 @@ class EMRContainersClient(BaseClient):
         self, operation_name: Literal["list_virtual_clusters"]
     ) -> ListVirtualClustersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.4/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listvirtualclusterspaginator)
         """
